@@ -188,7 +188,7 @@ export const CreateRecordedQueryUnconnected = ({ query, queries, dataSource, var
         : q;
 
       const idQ = interpolatedTarget as IdDataQuery;
-      idQ.datasourceId = ds ? ds.id : -1;
+      idQ.datasourceId = ds?.id ? ds.id : -1;
       if (idQ.datasource === undefined) {
         if (q.datasource !== undefined && q.datasource !== null) {
           idQ.datasource = q.datasource;
